@@ -1,6 +1,5 @@
 # coding: utf-8
 import copy
-import logging
 import types
 
 from django.core.cache import cache
@@ -10,8 +9,8 @@ from django.db.models import Q, Value
 from django.db.models.functions import Concat, Substr
 from django.http import Http404
 from django.urls import reverse
-from django.utils.translation import trans_real
 from django.utils.translation import gettext_lazy as _
+from django.utils.translation import trans_real
 from modeltranslation import settings as mt_settings
 from modeltranslation.translator import NotRegistered, translator
 from modeltranslation.utils import build_localized_fieldname, get_language
@@ -20,13 +19,13 @@ from wagtail.admin.edit_handlers import (
     RichTextFieldPanel, StreamFieldPanel,
     extract_panel_definitions_from_model_class)
 from wagtail.contrib.routable_page.models import RoutablePageMixin
-from wagtail.core.fields import StreamField, StreamValue
-from wagtail.core.models import Page, Site, SiteRootPath
-from wagtail.core.url_routing import RouteResult
-from wagtail.core.utils import WAGTAIL_APPEND_SLASH
+from wagtail.fields import StreamField, StreamValue
+from wagtail.models import Page, Site, SiteRootPath
+from wagtail.coreutils import WAGTAIL_APPEND_SLASH
 from wagtail.images.edit_handlers import ImageChooserPanel
 from wagtail.search.index import SearchField
 from wagtail.snippets.views.snippets import SNIPPET_EDIT_HANDLERS
+from wagtail.url_routing import RouteResult
 
 from wagtail_modeltranslation.patch_wagtailadmin_forms import \
     patch_admin_page_form
@@ -36,8 +35,6 @@ from wagtail_modeltranslation.settings import (CUSTOM_COMPOSED_PANELS,
                                                TRANSLATE_SLUGS)
 from wagtail_modeltranslation.utils import compare_class_tree_depth
 
-logger = logging.getLogger('wagtail.core')
-
 SIMPLE_PANEL_CLASSES = [FieldPanel, ImageChooserPanel, StreamFieldPanel, RichTextFieldPanel] + CUSTOM_SIMPLE_PANELS
 COMPOSED_PANEL_CLASSES = [MultiFieldPanel, FieldRowPanel] + CUSTOM_COMPOSED_PANELS
 INLINE_PANEL_CLASSES = [InlinePanel] + CUSTOM_INLINE_PANELS
@@ -142,7 +139,7 @@ class WagtailTranslator(object):
             translation_registered_fields = translator.get_options_for_model(model).fields
             panels = list(filter(lambda field: field.field_name not in translation_registered_fields, panels))
             edit_handler = ObjectList(panels)
-            SNIPPET_EDIT_HANDLERS[model] = edit_handler.bind_to(model=model)
+            SNIPPET_EDIT_HANDLERS[model] = edit_handler.bind_to_model(model=model)
 
     def _patch_panels(self, panels_list, related_model=None):
         """
